]> https://gitweb.dealii.org/ - candi.git/commitdiff
candi: introducing a new keyword 'load' for package handling.
authorUwe Köcher <koecher@hsu-hamburg.de>
Tue, 6 Oct 2015 15:49:56 +0000 (17:49 +0200)
committerUwe Köcher <koecher@hsu-hamburg.de>
Tue, 6 Oct 2015 15:49:56 +0000 (17:49 +0200)
Details: preparation packages such as dealii-prepare were set to skip:dealii-prepare
which is confusing the users.
The patch of this branch introduces a new keyword load for optimising the user
experience.

candi.sh
deal.II/platforms/supported/centos7.platform
deal.II/platforms/supported/fedora21.platform
deal.II/platforms/supported/fedora22.platform
deal.II/platforms/supported/linux_cluster.platform
deal.II/platforms/supported/opensuse12.platform
deal.II/platforms/supported/opensuse13.platform
deal.II/platforms/supported/rhel6.platform
deal.II/platforms/supported/rhel7.platform
deal.II/platforms/supported/ubuntu14.platform
deal.II/platforms/supported/ubuntu15.platform

index 45a63916698d44ade3762cbbab098098758ec19e..43c935e0e779379c8da8f7b1283d48057f8914a6 100755 (executable)
--- a/candi.sh
+++ b/candi.sh
@@ -680,6 +680,7 @@ for PACKAGE in ${PACKAGES[@]}; do
     # Skip building this package if the user requests it
     SKIP=false
     case ${PACKAGE} in
+        load:*) SKIP=true; LOAD=true; PACKAGE=${PACKAGE#*:};;
         skip:*) SKIP=true;  PACKAGE=${PACKAGE#*:};;
         once:*) 
           # If the package is turned off in the deal.II configuration, do not
@@ -762,8 +763,13 @@ for PACKAGE in ${PACKAGES[@]}; do
         package_unpack
         package_build
     else
-        # Let the user know we're skipping the current package
-        cecho ${GOOD} "Skipping ${NAME}"
+        if [ ! -z "${LOAD}" ]; then
+            # Let the user know we're loading the current package
+            cecho ${GOOD} "Loading ${NAME}"
+        else
+            # Let the user know we're skipping the current package
+            cecho ${GOOD} "Skipping ${NAME}"
+        fi
     fi
     package_register
     package_conf
index a9649a30fa40d93d4e1832583c726dc6d5c8a448..2f5c07378b6cf250508c8d6ffa9935d8cf563e21 100644 (file)
@@ -22,7 +22,7 @@
 #
 # Define the packages this platform needs
 PACKAGES=(
-skip:dealii-prepare
+load:dealii-prepare
 once:parmetis
 once:superlu_dist
 once:hdf5
index 0bbf7f64056ed23f60f6fdafb14b9c57f124b2ce..5e00d9431a56211fcd162545493b172599242961 100644 (file)
@@ -24,7 +24,7 @@
 #
 # Define the packages this platform needs
 PACKAGES=(
-skip:dealii-prepare
+load:dealii-prepare
 #once:boost
 once:parmetis
 once:superlu_dist
index 4e186cf7fe3edd8132650bf2e3cc9cce38fd363c..1a1038ac01ad4a715b0b9848850fe3b3fd636f52 100644 (file)
@@ -24,7 +24,7 @@
 #
 # Define the packages this platform needs
 PACKAGES=(
-skip:dealii-prepare
+load:dealii-prepare
 once:parmetis
 once:superlu_dist
 once:hdf5
index 95d154e6630f77a26fd15a7c22f7b3a27361b2a5..de9aba3bad6897a3129b808bd1ca14f874b16f22 100644 (file)
@@ -17,7 +17,7 @@
 #
 # Define the packages this platform needs
 PACKAGES=(
-skip:dealii-prepare
+load:dealii-prepare
 once:zlib
 once:bzip2
 once:boost
index ad5431abe9b74025d698d18c8c888f86febf67d4..147170e6b126b05ecca7243a3b40bb9a566f44ff 100644 (file)
@@ -22,7 +22,7 @@
 #
 # Define the packages this platform needs
 PACKAGES=(
-skip:dealii-prepare
+load:dealii-prepare
 #once:boost
 once:parmetis
 once:superlu_dist
index 4404e42a22b60c7b80f17982dfdaaab7c297c640..0dbbfdb10ed4fa2ef5c2f5f294be87fc19f860de 100644 (file)
@@ -17,7 +17,7 @@
 #
 # Define the packages this platform needs
 PACKAGES=(
-skip:dealii-prepare
+load:dealii-prepare
 #once:boost
 once:parmetis
 once:superlu_dist
index 5d1c2eea380868f86082cb1773d25fdb8031b6fe..861b85f11ec626aef282fb53ca8ffda4bb30bba7 100644 (file)
@@ -17,6 +17,7 @@
 #
 # Define the packages this platform needs
 PACKAGES=(
+load:dealii-prepare
 once:parmetis
 once:superlu_dist
 once:hdf5
index a12f3933fc38e60e12f8bf14b3a9a1589600ef1d..2654aa04609eaddda9256cf576d79d109f65b357 100644 (file)
@@ -19,6 +19,7 @@
 #
 # Define the packages this platform needs
 PACKAGES=(
+load:dealii-prepare
 once:parmetis
 once:superlu_dist
 once:hdf5
index fcf6cf5bb19198a71358c55d70fe24a251964c12..1585b6e01f9eee2aece8d5d398380c71de34fab7 100644 (file)
@@ -11,7 +11,7 @@
 #
 # Define the packages this platform needs
 PACKAGES=(
-skip:dealii-prepare
+load:dealii-prepare
 once:parmetis
 once:superlu_dist
 once:hdf5
index e3905aa4e9f84c17d7cc0acb92b7494c3e3ab8be..097c1b7d570a782648274cb367dfb4247714c55c 100644 (file)
@@ -11,7 +11,7 @@
 #
 # Define the packages this platform needs
 PACKAGES=(
-skip:dealii-prepare
+load:dealii-prepare
 once:parmetis
 once:superlu_dist
 once:hdf5

In the beginning the Universe was created. This has made a lot of people very angry and has been widely regarded as a bad move.

Douglas Adams


Typeset in Trocchi and Trocchi Bold Sans Serif.